pub struct Packages { /* private fields */ }Implementations
Sourceimpl Packages
impl Packages
pub fn new<P, N>( path: PathBuf, packages: &[P], root_package: Option<&P>, default_members: Vec<N>, ) -> Result<Self>
pub fn cargo_file_path(&self) -> &PathBuf
pub fn drop_root_package_name(&mut self)
pub fn workspace_default_members(&self) -> HashSet<&PackageName>
pub fn workspace_members(&self) -> HashSet<&PackageName>
Sourcepub fn set_root_package_name<'name>(
&mut self,
package_name: &'name PackageName,
) -> Option<&'name PackageName>
pub fn set_root_package_name<'name>( &mut self, package_name: &'name PackageName, ) -> Option<&'name PackageName>
Trys to set root package name, returns None if package doesn’t exist or an invalid name is inputed.
Use Packages::try_set_root_package_name if you want to see the error.
pub fn try_set_root_package_name<'name>( &mut self, package_name: &'name PackageName, ) -> Result<&'name PackageName>
Sourcepub fn root_package_name_unchecked(&self) -> Option<&PackageName>
pub fn root_package_name_unchecked(&self) -> Option<&PackageName>
Only needs a &self as it returns what is set.
Sourcepub fn root_package_name(&mut self) -> Option<&PackageName>
pub fn root_package_name(&mut self) -> Option<&PackageName>
Validated the set root name, uses Packages::drop_root_package_name if root_name is invalid.
Sourcepub fn get_root_package(&self) -> Option<&Package<ReadToml>>
pub fn get_root_package(&self) -> Option<&Package<ReadToml>>
Checks whether there is a root name and returns a ref to the root_package.
Sourcepub fn get_root_package_mut(&mut self) -> Option<&mut Package<ReadToml>>
pub fn get_root_package_mut(&mut self) -> Option<&mut Package<ReadToml>>
Checks whether there is a root name and returns a mut ref to the root_package.
Sourcepub fn get_root_package_owned(&self) -> Option<Package<ReadToml>>
pub fn get_root_package_owned(&self) -> Option<Package<ReadToml>>
Checks whether there is a root name and returns an owned clone of the root_package.
Sourcepub fn get_package(
&self,
package_name: &PackageName,
) -> Option<&Package<ReadToml>>
pub fn get_package( &self, package_name: &PackageName, ) -> Option<&Package<ReadToml>>
Uses the HashMap::get and returns a ref to the Package if it exists.
Sourcepub fn get_package_mut(
&mut self,
package_name: &PackageName,
) -> Option<&mut Package<ReadToml>>
pub fn get_package_mut( &mut self, package_name: &PackageName, ) -> Option<&mut Package<ReadToml>>
Uses the HashMap::get_mut and returns a mut ref to the Package if it exists.
Sourcepub fn get_package_owned(
&self,
package_name: &PackageName,
) -> Option<Package<ReadToml>>
pub fn get_package_owned( &self, package_name: &PackageName, ) -> Option<Package<ReadToml>>
Uses the HashMap::get followed by Option::cloned and returns Package if it exists.
pub fn packages(&self) -> &HashMap<PackageName, Package<ReadToml>>
pub fn package_set(&self) -> HashSet<&Package<ReadToml>>
pub fn set_cargo_file_path(&mut self, cargo_file: PathBuf)
Sourcepub fn root_version(&self) -> Result<Version, PackageError>
pub fn root_version(&self) -> Result<Version, PackageError>
Determine what the root version is for the packages.
Order of checks:
- root version is set
- root package version
- workplace.package.version
- TODO: If all versions are the same use that version
pub fn workspace_package(&mut self) -> Option<&mut Package<ReadToml>>